==> goods-center-biz-1.9.7-20170227.111408-3-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/impl/RemoteImmediatelyButtonServiceImpl.java <==
package cn.com.duiba.goods.center.biz.remoteservice.impl;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import cn.com.duiba.dcommons.enums.GoodsTypeEnum;
import cn.com.duiba.goods.center.api.remoteservice.dto.ImmediatelyButtonDto;
import cn.com.duiba.goods.center.api.remoteservice.front.RemoteImmediatelyButtonService;
import cn.com.duiba.goods.center.biz.bo.ImmediatelyButtonBackendBo;
import cn.com.duiba.goods.center.common.ErrorCode;
import cn.com.duiba.goods.center.common.RuntimeGoodsException;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * 马上使用按钮接口
 */
@Service
public class RemoteImmediatelyButtonServiceImpl implements RemoteImmediatelyButtonService {

	private static final Logger log = LoggerFactory.getLogger(RemoteImmediatelyButtonServiceImpl.class);

	@Resource
	private ImmediatelyButtonBackendBo immediatelyButtonBackendBo;

	@Override
	public DubboResult<String> selectImmediatelyButton(Long gid, GoodsTypeEnum gtype, Long orderId, String userAgent, String hdtoolFalg, String urlParameter, String embedClickurl) {
		try {
			if (gid == null || gtype == null || userAgent == null || hdtoolFalg == null) {
				throw new RuntimeGoodsException(ErrorCode.E0404004);
			}
			String ret = immediatelyButtonBackendBo.selectImmediatelyButtonFromItem(gid, gtype, orderId, userAgent, hdtoolFalg, urlParameter, embedClickurl);
			return DubboResult.successResult(ret);
		} catch (RuntimeGoodsException e) {
			log.warn("selectImmediatelyButtonFromCoupon:gid=" + gid + ",gtype=" + gtype + ",orderId= " + orderId + ",userAgent:" + userAgent + ",hdtoolFalg= " + hdtoolFalg + ",urlParameter=" + urlParameter + ",embedClickurl=" + embedClickurl);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<String> selectImmediatelyButtonFromCoupon(Long couponId, Long itemId, Long orderId, String urlParameter, String embedClickurl, String hdtoolFalg) {
		try {
			if (itemId == null || orderId == null || couponId == null) {
				throw new RuntimeGoodsException(ErrorCode.E0404004);
			}
			String ret = immediatelyButtonBackendBo.selectImmediatelyButtonFromCoupon(couponId, itemId, orderId, urlParameter, embedClickurl);
			return DubboResult.successResult(ret);
		} catch (RuntimeGoodsException e) {
			log.warn("selectImmediatelyButtonFromCoupon:couponId=" + couponId + ",itemId=" + itemId + ",orderId=" + orderId + ",urlParameter:" + urlParameter + ",embedClickurl=" + embedClickurl + ",hdtoolFalg=" + hdtoolFalg);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<ImmediatelyButtonDto> selectImmediatelyForPlatfrom(Long gid, GoodsTypeEnum gtype, Long orderId, String userAgent, String hdtoolFalg, String consunmerId) {
		try {
			if (gid == null || gtype == null || userAgent == null || hdtoolFalg == null) {
				throw new RuntimeGoodsException(ErrorCode.E0404004);
			}
			ImmediatelyButtonDto ret = immediatelyButtonBackendBo.selectImmediatelyForPlatfrom(gid, gtype, orderId, userAgent, hdtoolFalg, consunmerId);
			return DubboResult.successResult(ret);
		} catch (RuntimeGoodsException e) {
			log.warn("selectImmediatelyForPlatFrom:gid=" + gid + ",gtype=" + gtype + ",orderId=" + orderId + ",userAgent:" + userAgent + ",hdtoolFalg=" + hdtoolFalg + ",consunmerId=" + consunmerId);
			return DubboResult.failResult(e.getMessage());
		}
	}

}

==> goods-center-biz-2.0.0.7-20170517.104517-2-sources.jar: cn/com/duiba/goods/center/biz/remoteservice/impl/RemoteImmediatelyButtonServiceImpl.java <==
package cn.com.duiba.goods.center.biz.remoteservice.impl;

import javax.annotation.Resource;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import cn.com.duiba.dcommons.enums.GoodsTypeEnum;
import cn.com.duiba.goods.center.api.remoteservice.dto.ImmediatelyButtonDto;
import cn.com.duiba.goods.center.api.remoteservice.front.RemoteImmediatelyButtonService;
import cn.com.duiba.goods.center.biz.bo.ImmediatelyButtonBackendBo;
import cn.com.duiba.goods.center.common.ErrorCode;
import cn.com.duiba.goods.center.common.RuntimeGoodsException;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * 马上使用按钮接口
 */
@Service("remoteImmediatelyButtonService")
public class RemoteImmediatelyButtonServiceImpl implements RemoteImmediatelyButtonService {

	private static final Logger log = LoggerFactory.getLogger(RemoteImmediatelyButtonServiceImpl.class);

	@Resource
	private ImmediatelyButtonBackendBo immediatelyButtonBackendBo;

	@Override
	public DubboResult<String> selectImmediatelyButton(Long gid, GoodsTypeEnum gtype, Long orderId, String userAgent, String hdtoolFalg, String urlParameter, String embedClickurl) {
		try {
			if (gid == null || gtype == null || userAgent == null || hdtoolFalg == null) {
				throw new RuntimeGoodsException(ErrorCode.E0404004);
			}
			String ret = immediatelyButtonBackendBo.selectImmediatelyButtonFromItem(gid, gtype, orderId, userAgent, hdtoolFalg, urlParameter, embedClickurl);
			return DubboResult.successResult(ret);
		} catch (RuntimeGoodsException e) {
			log.warn("selectImmediatelyButtonFromCoupon:gid=" + gid + ",gtype=" + gtype + ",orderId= " + orderId + ",userAgent:" + userAgent + ",hdtoolFalg= " + hdtoolFalg + ",urlParameter=" + urlParameter + ",embedClickurl=" + embedClickurl, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<String> selectImmediatelyButtonFromCoupon(Long couponId, Long itemId, Long orderId, String urlParameter, String embedClickurl, String hdtoolFalg) {
		try {
			if (itemId == null || orderId == null || couponId == null) {
				throw new RuntimeGoodsException(ErrorCode.E0404004);
			}
			String ret = immediatelyButtonBackendBo.selectImmediatelyButtonFromCoupon(couponId, itemId, orderId, urlParameter, embedClickurl);
			return DubboResult.successResult(ret);
		} catch (RuntimeGoodsException e) {
			log.warn("selectImmediatelyButtonFromCoupon:couponId=" + couponId + ",itemId=" + itemId + ",orderId=" + orderId + ",urlParameter:" + urlParameter + ",embedClickurl=" + embedClickurl + ",hdtoolFalg=" + hdtoolFalg, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

	@Override
	public DubboResult<ImmediatelyButtonDto> selectImmediatelyForPlatfrom(Long gid, GoodsTypeEnum gtype, Long orderId, String userAgent, String hdtoolFalg, String consunmerId) {
		try {
			if (gid == null || gtype == null || userAgent == null || hdtoolFalg == null) {
				throw new RuntimeGoodsException(ErrorCode.E0404004);
			}
			ImmediatelyButtonDto ret = immediatelyButtonBackendBo.selectImmediatelyForPlatfrom(gid, gtype, orderId, userAgent, hdtoolFalg, consunmerId);
			return DubboResult.successResult(ret);
		} catch (RuntimeGoodsException e) {
			log.warn("selectImmediatelyForPlatFrom:gid=" + gid + ",gtype=" + gtype + ",orderId=" + orderId + ",userAgent:" + userAgent + ",hdtoolFalg=" + hdtoolFalg + ",consunmerId=" + consunmerId, e);
			return DubboResult.failResult(e.getMessage());
		}
	}

}
